/**********************************************************************************************
* Device      : AD122
* Author      :
* Version     : V1.0.0
* Date        : 2023.11.05
* Description : DAC的参考电压选择VDD，DAC输出的电压通过FVR输出到PB3；
***********************************************************************************************/
#include "AD122.h"
#include <stdio.h>
#include "periph.h"
/*********************************************************************************************
*
* _FINTOSC_DIV1   :  内部RC振荡器频率选择
* _DBG_OFF        :  DEBUG模式使能位
* _LVREN_OFF       :  禁止LVR
* _LVR24V         :  LVR的电压选择为2.4V
* _FLASH_CP1_OFF  :  1K~2K*16 FLASH CP保护
* _FLASH_CP0_OFF  :  0~1K*16 FLASH CP保护
* _IDIS_OFF       :  模拟IO打开，数据读取控制位
* _CKSUM_OFF      :  校验使能位
* _CBP_OFF        :  代码保护选择位
* _RESETE_OFF     :  外部复位使能
* _RSEL		      :  端口上下拉电阻选择
* _STV_ON         :  堆栈溢出复位
* _PSUT_2         :  上电复位时间选择
* _FCPU_4T        :  指令周期选择4T
* _WDTE_OFF       :  看门狗使能
* _TWDT_000       :  看门狗溢出时间选择
* _OSCM_HIRC_16M  :  系统时钟选择高速时钟
* _MTPDIS_OFF     :  SWD模式下读FALSH控制
* _ADCSP_ON       :	 ADC采集速度选择
*

************************************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _DBG_OFF_1L       & _LVREN_OFF_1L     & _LVR24V_1L                                                                   );
__CONFIG(2,_FLASH_CP1_OFF_2L    & _FLASH_CP0_OFF_2L & _IDIS_OFF_2L     & _CKSUM_OFF_2L  & _CBP_OFF_2L   & _RESETE_OFF_2L & _RSEL_LOW_2L & _STV_ON_2L  );
__CONFIG(3,_PSUT_2_3L           & _FCPU_4T_3L       & _WDTE_OFF_3L    & _TWDT_100_3L                                                                 );
__CONFIG(4,_OSCM_HIRC_16M_4L    & _ADCSP_ON_4L                                                                                                        );

volatile unsigned char Chip_ID = 0;

void main(void)
{
     unsigned char  i;

     GPIO_Init();//GPIO 初始化
     TRISB3  = 1;//设置PB3为输入模式;
     ANASEL1 =0x08;//打开PB3的模拟通道
     FVRCON0 = 0x64;//使能FVROUT，FVR的放大倍数选择1倍，通道选择DACOUT，使能FVR输出，通过PB3输出
     while(1)
      {
        for ( i = 0; i < 16; i++)
            {   TRISB0 =0 ;
                    PB0 = 1;
    //                         参考电压VDD       抽头选择   DAC输出     DAC使能
                DAC_Config(    DAC_VDD,        DAC_0,    i,        DAC_EN  );

                __delay_ms(8000);
                PB0 = 0;
                __delay_ms(8000);

            }
        for ( i = 0; i < 16; i++)
            {
                TRISB0 =0 ;
                    PB0 = 1;
    //                         参考电压VDD       抽头选择   DAC输出     DAC使能
                DAC_Config(    DAC_VDD,        DAC_1,    i,        DAC_EN  );

                __delay_ms(8000);
                    PB0 = 0;
                __delay_ms(8000);

            }

        for ( i = 0; i < 16; i++)
            {
                TRISB0 =0 ;
                    PB0 = 1;
    //                         参考电压VDD       抽头选择   DAC输出     DAC使能
                DAC_Config(    DAC_VDD,        DAC_2,    i,        DAC_EN  );

                __delay_ms(8000);
                    PB0 = 0;
                __delay_ms(8000);
            }
        for ( i = 0; i < 16; i++)
            {
                    TRISB0 =0 ;
                    PB0 = 1;
    //                         参考电压VDD       抽头选择   DAC输出     DAC使能
                DAC_Config(    DAC_VDD,        DAC_3,    i,        DAC_EN  );
                __delay_ms(8000);
                    PB0 = 0;
                __delay_ms(8000);
            }
     }
}

//高优先级中断服务函数

void interrupt ISR_h (void)
{
//进入中断后系统自动关闭中断



}

//低优先级中断服务函数

void interrupt low_priority ISR_l (void)
{


}


