/**********************************************************************************************
* Device      : AD122
* Author      : ADUC AE Team
* Version     : V1.0.0
* Date        : 2023.11.24
* Description : 清SRAM汇编，
                编译后会有警告（1352）
***********************************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include "AD122.h"
/*********************************************************************************************
* 常用配置字功能说明：
*
* _FINTOSC_DIV1     :  内部时钟分频选择
* _DBG_OFF          :  禁用DEBUG模式（使能后DEBUG 口不能做普通IO用）
* _LVREN_OFF         :  LVR使能位
* _LVT24V           :  选择LVR电压为2.4V
* _FLASH_CP1_OFF    :  1K~2K*16 FLASH保护位
* _FLASH_CP0_OFF    :  0~1K*16 FLASH保护位
* _IDIS_OFF	     	:  模拟IO打开，数据读取控制位
* _CKSUM_OFF        :  使能程序校验
* _CBP_OFF			:  代码保护选择位
* _RESETE_OFF       :  禁用外部复位
* _RSEL				:  端口上下拉电阻选择
* _STV_ON		    :  堆栈溢出复位使能位
* _PSUT_2		    :  上电复位时间选择位
* _FCPU_4T          :  选择指令周期为4T模式
* _WDTEN_OFF        :  看门狗使能位
* _TWDT_000         :  看门狗溢出时间选择位
* _OSCM_HIRC_16M    :  选择内部高速时钟16MHz
* _ADCSP_ON			:  ADC采集速度选择位

*
* 注意：1.配置字若无特别需求请勿修改；
*       2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/
__CONFIG(1,_FINTOSC_DIV1_1L     & _DBG_OFF_1L       & _LVREN_OFF_1L     & _LVR24V_1L                                                                    );
__CONFIG(2,_FLASH_CP1_OFF_2L    & _FLASH_CP0_OFF_2L & _IDIS_OFF_2L      & _CKSUM_OFF_2L  & _CBP_OFF_2L   & _RESETE_OFF_2L & _RSEL_LOW_2L & _STV_ON_2L   );
__CONFIG(3,_PSUT_2_3L           & _FCPU_4T_3L       & _WDTE_OFF_3L      & _TWDT_100_3L                                                                  );
__CONFIG(4,_OSCM_HIRC_16M_4L    & _MTPDIS_OFF_4L    & _ADCSP_ON_4L                                                                                      );

//清SRAM
void sram_init()
{
	#asm
		INDF		EQU 0xFEF
		FSR0L		EQU 0xFE9
		FSR0H		EQU 0xFEA
		STATUS		EQU 0xfd8

		MOVLW 00h
		MOVWF FSR0L
	T0 :
		MOVLW 00H
		MOVWF INDF
		INCF  FSR0L
		MOVF  FSR0L,W
		XORLW 0x100
		BTFSS STATUS,2
		GOTO T0

		MOVLW 01h
		MOVWF FSR0H
		MOVLw 00h
		MOVWF FSR0L
	T1 :
		MOVLW 00H
		MOVWF INDF
		INCF  FSR0L
		MOVF  FSR0L,W
		XORLW 0X100
		BTFSS STATUS,2
		GOTO T1
	#endasm
}

void main(void)
{
	sram_init();

	while(1)
	{

	}
}

