/**********************************************************************************************
* Device      : AD122
* Author      : TANWENBO
* Version     : V1.0.0
* Date        : 2023.11.11
* Description : 演示配置tmr1的不同分频测试
***********************************************************************************************/

#include "AD122.h"




/*********************************************************************************************
* 常用配置字功能说明：
*
* _FINTOSC_DIV1     :  内部时钟分频选择
* _DBG_OFF          :  禁用DEBUG模式（使能后DEBUG口不能做普通IO用）
* _LVREN_ON         :  使能LVR
* _LVR24V           :  选择LVR电压为2.4V
* _FLASH_CP1_OFF    :  1K~2K*16 FLASH保护位
* _FLASH_CP0_OFF    :  0~1K*16 FLASH保护位
* _IDIS_OFF	     	:  模拟IO打开，数据读取控制位
* _CKSUM_OFF        :  使能程序校验
* _CBP_OFF			:  代码保护选择位
* _RESETE_OFF       :  禁用外部复位
* _RSEL				:  端口上下拉电阻选择
* _STV_ON		    :  堆栈溢出复位使能位
* _PSUT_2		    :  上电复位时间选择位
* _FCPU_4T          :  选择指令周期为4T模式
* _WDTE_OFF         :  看门狗使能位
* _TWDT_000         :  看门狗溢出时间选择位
* _OSCM_HIRC_16M    :  选择内部高速时钟16MHz
* _ADCSP_ON			:  ADC采集速度选择位
* 注意：1.配置字若无特别需求请勿修改；
*       2.其他配置字及相应功能见头文件；
************************************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _DBG_OFF_1L       & _LVREN_OFF_1L    & _LVR24V_1L                                                  );
__CONFIG(2,_FLASH_CP1_OFF_2L    & _FLASH_CP0_OFF_2L & _IDIS_OFF_2L     & _CKSUM_OFF_2L  & _CBP_OFF_2L   & _RESETE_OFF_2L & _RSEL_LOW_2L & _STV_ON_2L  );
__CONFIG(3,_PSUT_2_3L           & _FCPU_4T_3L       & _WDTE_OFF_3L    & _TWDT_100_3L                                                );
__CONFIG(4,_OSCM_HIRC_16M_4L    & _MTPDIS_OFF_4L    & _ADCSP_ON_4L                                                                                       );


void main (void)

{
    TMR1IF=0;
	TMR1IE=1;         //使能tmr1的中断
	IPEN = 1;	      //使能中断优先级
	GIEH=1;           //使能高优先级中断
	TRISA3=0;         //将PA3设置为输出模式
	T1CLKEN=1;        //使能timer1的时钟使能
    TMR1H=0xFC;
	TMR1L=0x18;

	/*---------------------------DIV1------------------------------------------*/

     T1CON0=0x01;   //使能Timer1定时器；选择FCPU作为timer1的时钟 div1         T = 500us
    /*---------------------------DIV2------------------------------------------*/

	// T1CON0=0x11; //使能Timer1定时器；选择FCPU作为timer1的时钟 div2         T = 1ms

	/*---------------------------DIV4------------------------------------------*/

	 //T1CON0=0x21; //使能Timer1定时器；选择FCPU作为timer1的时钟 div4         T = 2ms

	/*---------------------------DIV8------------------------------------------*/

	//T1CON0=0x31; //使能Timer1定时器；选择FCPU作为timer1的时钟 div8          T = 4ms


	while(1)
     {

     }
}

//高优先级中断服务函数

void interrupt ISR_h (void)
{
//进入中断后系统自动关闭中断
	if(TMR1IF==1  &&  TMR1IE==1)     //计满产生溢出中断
	{
		TMR1IF = 0;                  //清除中断
	    PA3=~PA3;                    //IO翻转
	}

}

//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{
//进入中断后系统自动关闭中断

}

